@@ -2,6 +2,8 @@ from .wdl import WDL
 from .deepfm import DeepFM
 from .xdeepfm import xDeepFM
 from .afm import AFM
+from .difm import DIFM
+from .ifm import IFM
 from .autoint import AutoInt
 from .dcn import DCN
 from .dcnmix import DCNMix
